%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FEASIBLE PERIODIC MOTION PRIMITIVES FOR CHOREOGRAPHED 
% QUADROCOPTER FLIGHT (submitted to ACC 2010)
% 
% **Periodic Motion Primitives** (Section II) 
%
% Angela Schoellig, Sept 2010 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all


%% define parameters

% length of Fourier series 
N = 4;

% fundamental frequency 
T = 1; % period 
w = 2*pi/T;

% amplitudes of sine [a0, a1, ..., aN], where a0,a1,etc. are column vectors
A = zeros(3,N+1);

A = [0 0 0 0 1
    0 0 0 0 0
    2 1 0 0 0];

% amplitudes of cosine [b1, ..., bN],  where b1,b2,etc. are column vectors
B = zeros(3,N);

B = [0 0  0 0  
    0  0 0 1
    0 0 0 0];



%% plot

% resolution
res = 500;
% plot style
sty = '.';
% periods
numT = 1;

t = (0:T/res:numT*T); % time in sec

% trajectory
s = A(:,1)*ones(1,length(t));

for k = 1:N
    s = s + A(:,k+1)*sin(k*w.*t) +  B(:,k)* cos(k*w.*t);
end


plot3(s(1,:), s(2,:), s(3,:),sty)
xlabel('x')
ylabel('y')
zlabel('z')
grid on

findfigs